##############################
Account UK VAT Analysis Module
##############################

The *Account UK VAT Analysis Module* adds tax codes which give an alternative
breakdown of UK VAT, sales and purchases.

.. toctree::
   :maxdepth: 2

   installation
   usage
   design
   support
   license
